@@ -1,12 +1,15 @@
 #include "client.h"
+
+#ifdef WITH_GREENLET
 #include "greensupport.h"
+#endif
 
 #define CLIENT_MAXFREELIST 1024
 
 static ClientObject *client_free_list[CLIENT_MAXFREELIST];
 static int client_numfree = 0;
 
-inline void
+void
 ClientObject_list_fill(void)
 {
     ClientObject *client;
@@ -16,7 +19,7 @@ ClientObject_list_fill(void)
     }
 }
 
-inline void
+void
 ClientObject_list_clear(void)
 {
     ClientObject *op;
@@ -27,40 +30,34 @@ ClientObject_list_clear(void)
     }
 }
 
-static inline ClientObject*
+static ClientObject*
 alloc_ClientObject(void)
 {
     ClientObject *client;
     if (client_numfree) {
         client = client_free_list[--client_numfree];
         _Py_NewReference((PyObject *)client);
-#ifdef DEBUG
-        printf("use pooled ClientObject %p\n", client);
-#endif
+        GDEBUG("use pooled %p", client);
     }else{
         client = PyObject_NEW(ClientObject, &ClientObjectType);
-#ifdef DEBUG
-        printf("alloc ClientObject %p\n", client);
-#endif
+        GDEBUG("alloc %p", client);
     }
     return client;
 }
 
-static inline void
+static  void
 dealloc_ClientObject(ClientObject *client)
 {
     Py_CLEAR(client->greenlet);
     if (client_numfree < CLIENT_MAXFREELIST){
-#ifdef DEBUG
-        printf("back to ClientObject pool %p\n", client);
-#endif
         client_free_list[client_numfree++] = client;
+        GDEBUG("back to pool %p", client);
     }else{
         PyObject_DEL(client);
     }
 }
 
-inline int 
+int
 CheckClientObject(PyObject *obj)
 {
     if (obj->ob_type != &ClientObjectType){
@@ -69,7 +66,7 @@ CheckClientObject(PyObject *obj)
     return 1;
 }
 
-inline PyObject* 
+ PyObject* 
 ClientObject_New(client_t* client)
 {
     ClientObject *o = alloc_ClientObject();
@@ -78,49 +75,33 @@ ClientObject_New(client_t* client)
         return NULL;
     }
 
-
     o->client = client;
     o->greenlet = NULL;
     o->args = NULL;
     o->kwargs = NULL;
-    o->suspended = 0;    
-    o->resumed = 0;    
+    o->suspended = 0;
+    /* o->resumed = 0; */
 
-#ifdef DEBUG
-    if(o->client){
-        printf("ClientObject_New pyclient:%p client:%p fd:%d \n", o, o->client, o->client->fd);
-    }else{
-        printf("ClientObject_New pyclient:%p client is null \n", o);
-    }
-#endif
-    
+    GDEBUG("ClientObject_New pyclient:%p client:%p fd:%d", o, o->client, o->client->fd);
     return (PyObject *)o;
 }
 
-static inline void
+static  void
 ClientObject_dealloc(ClientObject* self)
 {
 
-#ifdef DEBUG
-    if(self->client){
-        printf("ClientObject_dealloc pyclient:%p client:%p fd:%d \n", self, self->client, self->client->fd);
-    }else{
-        printf("ClientObject_dealloc pyclient:%p client is null \n", self);
-    }
-#endif
+    GDEBUG("ClientObject_dealloc pyclient:%p client:%p fd:%d", self, self->client, self->client->fd);
     //self->client = NULL;
-#ifdef DEBUG
-    printf("XDECREF greenlet:%p \n", self->greenlet);
-#endif
-    
+    DEBUG("XDECREF greenlet:%p", self->greenlet);
     dealloc_ClientObject(self);
     //Py_XDECREF(self->greenlet);
     //PyObject_DEL(self);
 }
 
-static inline PyObject *
+static  PyObject *
 ClientObject_set_greenlet(ClientObject *self, PyObject *args)
 {
+#ifdef WITH_GREENLET
     PyObject *temp;
 
     if (!PyArg_ParseTuple(args, "O:set_greenlet", &temp)){
@@ -130,7 +111,7 @@ ClientObject_set_greenlet(ClientObject *self, PyObject *args)
         PyErr_SetString(PyExc_TypeError, "must be greenlet object");
         return NULL;
     }
-    
+
     if(self->greenlet){
         // not set
         Py_RETURN_NONE;
@@ -138,26 +119,32 @@ ClientObject_set_greenlet(ClientObject *self, PyObject *args)
 
     Py_INCREF(temp);
     self->greenlet = temp;
-
     Py_RETURN_NONE;
+#else
+    NO_GREENLET_ERROR;
+#endif
 }
 
-static inline PyObject *
+static  PyObject*
 ClientObject_get_greenlet(ClientObject *self, PyObject *args)
 {
+#ifdef WITH_GREENLET
     if(self->greenlet){
         return (PyObject *)self->greenlet;
     }
     Py_RETURN_NONE;
+#else
+    NO_GREENLET_ERROR;
+#endif
 }
 
-static inline PyObject *
+static  PyObject *
 ClientObject_get_fd(ClientObject *self, PyObject *args)
 {
     return Py_BuildValue("i", self->client->fd);
 }
 
-static inline PyObject *
+static  PyObject *
 ClientObject_set_closed(ClientObject *self, PyObject *args)
 {
     int closed;
@@ -186,8 +173,12 @@ static PyMemberDef ClientObject_members[] = {
 
 
 PyTypeObject ClientObjectType = {
-    PyObject_HEAD_INIT(&PyType_Type)
-    0,
+#ifdef PY3
+    PyVarObject_HEAD_INIT(NULL, 0)
+#else
+    PyObject_HEAD_INIT(NULL)
+    0,                    /* ob_size */
+#endif
     "meinheld.client",             /*tp_name*/
     sizeof(ClientObject), /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -227,3 +218,4 @@ PyTypeObject ClientObjectType = {
     0,                           /* tp_new */
 };
 
+
